==> ec-rider0.8.1.tar.gz: ec-rider0.8.1/ec_admin/app/controllers/payments_controller.rb <==
# -*- coding: utf-8 -*-
class PaymentsController < ApplicationController
  class_desc :display_name => 'オンライン決済管理'

  desc :auth_as => :index
  # 検索条件を初期化してindexを開く
  def init_index
    session[:payments_search_cond] = nil
    redirect_to(:action => 'index')
  end

  def index
    if flash[:error]
      @condition = PaymentErrorHistory::SearchConditionForm.new(session[:payments_search_cond])
      @condition.valid?
      render(:action => 'search')
      return
    end

    @condition = if session[:payments_search_cond]
      PaymentErrorHistory::SearchConditionForm.new(session[:payments_search_cond])
    else
      now_date = Time.now.strftime('%Y/%m/%d')
      PaymentErrorHistory::SearchConditionForm.new(:exe_date_from => now_date, :exe_time_from => '00:00:00', :exe_date_to => now_date, :exe_time_to => '23:59:59')
    end
    render(:action => 'search')
  end


  desc :auth_as => :index
  def search
    if params[:condition]
      session[:payments_search_cond] = params[:condition]
    end

    @condition = PaymentErrorHistory::SearchConditionForm.new(session[:payments_search_cond])
    unless @condition.valid?
      flash[:error] = "error"
      redirect_to(:action => 'index')
      return
    end

    per_page = @condition.disp_count ? @condition.disp_count.to_i : 20
    condition = PaymentErrorHistory.create_condition(@condition)
    @histories = PaymentErrorHistory.paginate(:page => params[:page], :per_page => per_page, :conditions => condition, :order => "created_at desc")
    render(:action => 'search')
  end

  desc :category_name => :index, :display_name => 'ユーザー詳細'
  def user_detail
    @user = User.find(params[:id])
    @user_address = @user.user_address
  end

  desc :auth_as => :update
  # メール送信画面表示
  def mail
    history = PaymentErrorHistory.find(:first, :conditions => ["payment_system_div = ? AND updatable_id = ? ", params[:payment_system_div], params[:updatable_id]])
    user = history.updatable.user
    email = user.user_email.email
    # バリデーションエラーで戻った場合
    if flash[:mail_form]
      @mail_form = flash[:mail_form]

    else
      @mail_form = MailForm.new()
      @mail_form.from = ShopSetting[:shop_mail]
      @mail_form.to = email

      # メールテンプレートを取得
      template = MailTemplate.find_valid_template(:payment_error, history.updatable.locale)
      # メールテンプレートにバインドする変数を設定
      options = {:first_name => user.name_first, :last_name => user.name_last, :user_name => user.fullname, :email_address => email}
      # メールテンプレートに注文情報をバインドする
      pc_mobile_div = UserEmail.check_by_emall(email)
      @mail_form.subject = template.get_mail_subject(pc_mobile_div, options)
      @mail_form.body = template.get_mail_body(pc_mobile_div, options)
      @mail_form.locale = template.locale
    end
  end

  desc :auth_as => :update
  # メール送信 
  def send_mail
    @mail_form = MailForm.new(params[:mail_form])
    unless @mail_form.valid?
      flash[:mail_form] = @mail_form
      redirect_to :action => :mail, :payment_system_div => params[:payment_system_div], :updatable_id => params[:updatable_id], :page => params[:page]
      return
    end

    AdminMailer.send_free_mail(:payment_error, @mail_form.from, @mail_form.to, @mail_form.subject, @mail_form.body, @mail_form.locale)
    render(:action => "confirm_sent_mail")
  end


  desc :auth_as => :update
  # 編集フォーム 
  def update_form
    @history = PaymentErrorHistory.find(:first, :conditions => ["payment_system_div = ? AND updatable_id = ? ", params[:payment_system_div], params[:updatable_id]])
    @user = @history.updatable.user
    @email = @user.user_email if @user
    @address = @user.user_address if @user
  render(:action => "update_form")
  end

  # 更新
  def update
    history = PaymentErrorHistory.find(:first, :conditions => ["payment_system_div = ? AND updatable_id = ? ", params[:payment_system_div], params[:updatable_id]])
    history.updatable.status_div = params[:history][:status_div]
    history.updatable.save!
    redirect_to(:action => 'search', :page => params[:page])
  end

  # 削除
  def destroy
    GmoTransactionHistory.find(:all, :conditions => ["test_flg = ?", true]).each{|gmo| gmo.destroy!}
    SpsParameterHistory.find(:all, :conditions => ["test_flg = ?", true]).each{|sph| sph.destroy!}
    SpsResultHistory.find(:all, :conditions => ["test_flg = ?", true]).each{|srh| srh.destroy!}
    redirect_to(:action => 'search', :page => params[:page])
  end
end

==> ec-rider0.8.2.tar.gz: ec-rider0.8.2/ec_admin/app/controllers/payments_controller.rb <==
# -*- coding: utf-8 -*-
class PaymentsController < ApplicationController
  include EcRider::PluginModule::Extendable

  class_desc :display_name => 'オンライン決済管理'

  desc :auth_as => :index
  # 検索条件を初期化してindexを開く
  def init_index
    session[:payments_search_cond] = nil
    redirect_to(:action => 'index')
  end

  def index
    if flash[:error]
      @condition = PaymentErrorHistory::SearchConditionForm.new(session[:payments_search_cond])
      @condition.valid?
      render(:action => 'search')
      return
    end

    @condition = if session[:payments_search_cond]
      PaymentErrorHistory::SearchConditionForm.new(session[:payments_search_cond])
    else
      now_date = Time.now.strftime('%Y/%m/%d')
      PaymentErrorHistory::SearchConditionForm.new()
    end
    render(:action => 'search')
  end


  desc :auth_as => :index
  def search
    if params[:condition]
      session[:payments_search_cond] = params[:condition]
    end

    @condition = PaymentErrorHistory::SearchConditionForm.new(session[:payments_search_cond])
    unless @condition.valid?
      flash[:error] = "error"
      redirect_to(:action => 'index')
      return
    end

    per_page = @condition.disp_count ? @condition.disp_count.to_i : 20
    condition = PaymentErrorHistory.create_condition(@condition)
    @histories = PaymentErrorHistory.paginate(:page => params[:page], :per_page => per_page, :conditions => condition, :order => "created_at desc")
    render(:action => 'search')
  end

  desc :category_name => :index, :display_name => 'ユーザー詳細'
  def user_detail
    @user = User.find(params[:id])
    @user_address = @user.user_address
  end

  desc :auth_as => :update
  # メール送信画面表示
  def mail
    history = PaymentErrorHistory.find(params[:id])
    user = history.user
    order = history.order
    user_email = (order && order.site_type_div_key == :mobile) ? user.user_email_mobile : user.user_email
    email = user_email ? user_email.email : ''
    # バリデーションエラーで戻った場合
    if flash[:mail_form]
      @mail_form = flash[:mail_form]

    else
      @mail_form = MailForm.new()
      @mail_form.from = ShopSetting[:shop_mail]
      @mail_form.to = email

      # メールテンプレートを取得
      template = MailTemplate.find_valid_template(:payment_error, (history.order ? history.order.locale : nil))
      # メールテンプレートにバインドする変数を設定
      options = {:first_name => user.name_first, :last_name => user.name_last, :user_name => user.fullname, :email_address => email}
      # メールテンプレートに注文情報をバインドする
      pc_mobile_div = UserEmail.check_by_emall(email)
      @mail_form.subject = template.get_mail_subject(pc_mobile_div, options)
      @mail_form.body = template.get_mail_body(pc_mobile_div, options)
      @mail_form.locale = template.locale
    end
  end

  desc :auth_as => :update
  # メール送信 
  def send_mail
    @mail_form = MailForm.new(params[:mail_form])
    unless @mail_form.valid?
      flash[:mail_form] = @mail_form
      redirect_to :action => :mail, :id => params[:id], :page => params[:page]
      return
    end

    AdminMailer.send_free_mail(:payment_error, @mail_form.from, @mail_form.to, @mail_form.subject, @mail_form.body, @mail_form.locale)
    render(:action => "confirm_sent_mail")
  end


  desc :auth_as => :update
  # 編集フォーム 
  def update_form
    @history = PaymentErrorHistory.find(params[:id])
    @user = @history.user
    @email = @user.user_email if @user
    @address = @user.user_address if @user
  render(:action => "update_form")
  end

  # 更新
  def update
    history = PaymentErrorHistory.find(params[:id])
    history.update_status(params[:history][:status_div])
    redirect_to(:action => 'search', :page => params[:page])
  end

  # テストデータ削除
  def destroy
    PaymentErrorHistory.destroy_all_test_data
    redirect_to(:action => 'search', :page => params[:page])
  end
end
